AppTextStyle class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- appHeaderTextStyle ↔ TextStyle
-
getter/setter pair
- h3 ↔ TextStyle
-
getter/setter pair
- roboto500_28 ↔ TextStyle
-
getter/setter pair
- roboto600_48 ↔ TextStyle
-
getter/setter pair
- roboto_slab_500 ↔ TextStyle
-
getter/setter pair
- shrikhand_400 ↔ TextStyle
-
getter/setter pair
- subTitle ↔ TextStyle
-
getter/setter pair
- textFieldLableStyle ↔ TextStyle
-
getter/setter pair