AuthCubit class

Constructors

AuthCubit({required String redirectUri, required String scope, required String clientId})

Properties

clientId String
final
encodedScope String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isClosed bool
Whether the bloc is closed.
no setterinherited
redirectUri String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String
final
state AuthState
The current state.
no setterinherited
stream Stream<AuthState>
The current stream of states.
no setterinherited
user_flow String
getter/setter pair

Methods

addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
close() Future<void>
Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
inherited
emit(AuthState state) → void
Updates the state to the provided state. emit does nothing if the state being emitted is equal to the current state.
inherited
exchangeCodeForToken({required String code, required String flowName}) Future<Map<String, dynamic>>
getAuthrorisationCode(dynamic responseUri) Future<Map<String, dynamic>?>
isTokenExpired(String token) bool
loginFor(String userFlow, BuildContext context, {String hint = ''}) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(Change<AuthState> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
refreshAccessTokenUsingRefreshToken({required String refreshToken, required String flowName}) Future<Map<String, dynamic>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited